@@ -21,14 +21,19 @@ import networkx as nx
 
 from outdated import check_outdated # type: ignore
 
-from tgwrap.lib import TgWrap
+from .main import TgWrap
 
-from . import __version__
+from importlib.metadata import version, PackageNotFoundError
+__name__ = "tgwrap"
+try:
+    __version__ = version(__name__)
+except PackageNotFoundError:
+    __version__ = '0.0.0'
 
 def check_latest_version():
     # check for newer versions
     try:
-        is_outdated, latest_version = check_outdated('tgwrap', __version__)
+        is_outdated, latest_version = check_outdated(__name__, __version__)
         if is_outdated:
             click.echo(
                 f'Your local version ({__version__}) is out of date! Latest is {latest_version}!'
